==> flite-2.0.0-x86_64-1ponce.txz: install/doinst.sh <==
if ! grep "(flite)" usr/info/dir 1>/dev/null 2>/dev/null; then
  cat << EOF >> usr/info/dir

Miscellaneous
* FLITE:  (flite).                Flite, a small, fast speech synthesis engine.
EOF
fi
( cd usr/doc/flite-2.0.0/html ; rm -rf index.html )
( cd usr/doc/flite-2.0.0/html ; ln -sf flite_toc.html index.html )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lex.so.2.0.0 libflite_cmu_indic_lex.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_slt.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_slt.so.2.0.0 libflite_cmu_us_slt.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lex.so )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lex.so.1 libflite_cmu_indic_lex.so )
( cd usr/lib64 ; rm -rf libflite_cmulex.so )
( cd usr/lib64 ; ln -sf libflite_cmulex.so.1 libflite_cmulex.so )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lang.so )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lang.so.1 libflite_cmu_grapheme_lang.so )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lang.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lang.so.2.0.0 libflite_cmu_indic_lang.so.1 )
( cd usr/lib64 ; rm -rf libflite_usenglish.so.1 )
( cd usr/lib64 ; ln -sf libflite_usenglish.so.2.0.0 libflite_usenglish.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal.so.2.0.0 libflite_cmu_us_kal.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_time_awb.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_time_awb.so.2.0.0 libflite_cmu_time_awb.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lang.so )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lang.so.1 libflite_cmu_indic_lang.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal16.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal16.so.2.0.0 libflite_cmu_us_kal16.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lang.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lang.so.2.0.0 libflite_cmu_grapheme_lang.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lex.so.2.0.0 libflite_cmu_grapheme_lex.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal16.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal16.so.1 libflite_cmu_us_kal16.so )
( cd usr/lib64 ; rm -rf libflite.so )
( cd usr/lib64 ; ln -sf libflite.so.1 libflite.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal.so.1 libflite_cmu_us_kal.so )
( cd usr/lib64 ; rm -rf libflite.so.1 )
( cd usr/lib64 ; ln -sf libflite.so.2.0.0 libflite.so.1 )
( cd usr/lib64 ; rm -rf libflite_usenglish.so )
( cd usr/lib64 ; ln -sf libflite_usenglish.so.1 libflite_usenglish.so )
( cd usr/lib64 ; rm -rf libflite_cmu_time_awb.so )
( cd usr/lib64 ; ln -sf libflite_cmu_time_awb.so.1 libflite_cmu_time_awb.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_rms.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_rms.so.1 libflite_cmu_us_rms.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_awb.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_awb.so.2.0.0 libflite_cmu_us_awb.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lex.so )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lex.so.1 libflite_cmu_grapheme_lex.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_slt.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_slt.so.1 libflite_cmu_us_slt.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_awb.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_awb.so.1 libflite_cmu_us_awb.so )
( cd usr/lib64 ; rm -rf libflite_cmulex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmulex.so.2.0.0 libflite_cmulex.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_rms.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_rms.so.2.0.0 libflite_cmu_us_rms.so.1 )

==> flite-2.2-x86_64-1ponce.txz: install/doinst.sh <==
if ! grep "(flite)" usr/info/dir 1>/dev/null 2>/dev/null; then
  cat << EOF >> usr/info/dir

Miscellaneous
* FLITE:  (flite).                Flite, a small, fast speech synthesis engine.
EOF
fi
( cd usr/doc/flite-2.2/html ; rm -rf index.html )
( cd usr/doc/flite-2.2/html ; ln -sf flite_toc.html index.html )
( cd usr/lib64 ; rm -rf libflite.so )
( cd usr/lib64 ; ln -sf libflite.so.1 libflite.so )
( cd usr/lib64 ; rm -rf libflite.so.1 )
( cd usr/lib64 ; ln -sf libflite.so.2.2 libflite.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lang.so )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lang.so.1 libflite_cmu_grapheme_lang.so )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lang.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lang.so.2.2 libflite_cmu_grapheme_lang.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lex.so )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lex.so.1 libflite_cmu_grapheme_lex.so )
( cd usr/lib64 ; rm -rf libflite_cmu_grapheme_lex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_grapheme_lex.so.2.2 libflite_cmu_grapheme_lex.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lang.so )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lang.so.1 libflite_cmu_indic_lang.so )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lang.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lang.so.2.2 libflite_cmu_indic_lang.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lex.so )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lex.so.1 libflite_cmu_indic_lex.so )
( cd usr/lib64 ; rm -rf libflite_cmu_indic_lex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_indic_lex.so.2.2 libflite_cmu_indic_lex.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_time_awb.so )
( cd usr/lib64 ; ln -sf libflite_cmu_time_awb.so.1 libflite_cmu_time_awb.so )
( cd usr/lib64 ; rm -rf libflite_cmu_time_awb.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_time_awb.so.2.2 libflite_cmu_time_awb.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_awb.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_awb.so.1 libflite_cmu_us_awb.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_awb.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_awb.so.2.2 libflite_cmu_us_awb.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal.so.1 libflite_cmu_us_kal.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal.so.2.2 libflite_cmu_us_kal.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal16.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal16.so.1 libflite_cmu_us_kal16.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_kal16.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_kal16.so.2.2 libflite_cmu_us_kal16.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_rms.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_rms.so.1 libflite_cmu_us_rms.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_rms.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_rms.so.2.2 libflite_cmu_us_rms.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmu_us_slt.so )
( cd usr/lib64 ; ln -sf libflite_cmu_us_slt.so.1 libflite_cmu_us_slt.so )
( cd usr/lib64 ; rm -rf libflite_cmu_us_slt.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmu_us_slt.so.2.2 libflite_cmu_us_slt.so.1 )
( cd usr/lib64 ; rm -rf libflite_cmulex.so )
( cd usr/lib64 ; ln -sf libflite_cmulex.so.1 libflite_cmulex.so )
( cd usr/lib64 ; rm -rf libflite_cmulex.so.1 )
( cd usr/lib64 ; ln -sf libflite_cmulex.so.2.2 libflite_cmulex.so.1 )
( cd usr/lib64 ; rm -rf libflite_usenglish.so )
( cd usr/lib64 ; ln -sf libflite_usenglish.so.1 libflite_usenglish.so )
( cd usr/lib64 ; rm -rf libflite_usenglish.so.1 )
( cd usr/lib64 ; ln -sf libflite_usenglish.so.2.2 libflite_usenglish.so.1 )
